import { number } from 'prop-types';
import React, { useState } from 'react';
import s from './PasswordConfirm.module.css';

interface IPasswordConfirmProps {
  min: number;
}
const PasswordConfirm = ({ min }: IPasswordConfirmProps) => {
  const [password, setPassword] = useState<string>('');
  const [passwordConfirm, setPasswordConfirm] = useState<string>('');
  const handlePassword = (e: React.ChangeEvent<HTMLInputElement>) => {
    const value = e.target.value;
    const name = e.target.name;
    switch (name) {
      case 'password':
        setPassword(value);
        break;
      case 'confirmPassword':
        setPasswordConfirm(value);
        break;
      default:
        break;
    }
  };

  const isValid = (password: string) => {
    const reg = '[^wd]*(([0-9]+.*[A-Za-z]+.*)|[A-Za-z]+.*([0-9]+.*))';
    return password && password.length >= min && new RegExp(reg).test(password)
      ? true
      : false;
  };

  const isConfirmed = () => {
    return password && passwordConfirm && password === passwordConfirm
      ? true
      : false;
  };

  return (
    <div className={s.passwordConfirmWrapper}>
      <input
        onChange={handlePassword}
        className={s.password}
        name="password"
        type="password"
      ></input>
      <p className={isValid(password) ? s.passwordValue : s.notValid}>
        password : {isValid(password) ? password : 'Password not valid'}
      </p>
      <input
        onChange={handlePassword}
        className={s.passwordConfirm}
        name="confirmPassword"
        type="password"
      ></input>
      <p
        className={
          isValid(passwordConfirm) ? s.confirmPasswordValue : s.notValid
        }
      >
        passwordConfirm :{' '}
        {isValid(passwordConfirm)
          ? passwordConfirm
          : ' PasswordConfirm not valid'}
      </p>
      <p className={isConfirmed() ? s.valid : s.notValid}>
        isPassword confirmed :{isConfirmed() ? ' confirmed!' : ' not confirmed'}
      </p>
    </div>
  );
};

export default PasswordConfirm;
